==> v0.5.tar.gz: garagecalc1/i18n/de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>TableWidget</name>
    <message>
        <location filename="clsTableWidget.py" line="87"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="88"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="89"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="258"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="108"/>
        <source>Cut row</source>
        <translation>Zeile ausschneiden</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="109"/>
        <source>Copy row</source>
        <translation>Zeile kopieren</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="110"/>
        <source>Paste row</source>
        <translation>Zeile einfügen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="112"/>
        <source>Insert row before</source>
        <translation>Zeile oberhalb einfügen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="113"/>
        <source>Insert row after</source>
        <translation>Zeile unterhalb einfügen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="115"/>
        <source>Remove row</source>
        <translation>Zeile entfernen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="116"/>
        <source>Delete items</source>
        <translation>Zellinhalte löschen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="151"/>
        <source>Row Nr.</source>
        <translation>Zeile Nr.</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="152"/>
        <source>to be removed?</source>
        <translation>entfernen?</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="152"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="258"/>
        <source>Delete cell content?</source>
        <translation>Zellinhalt löschen?</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="clsTableWidget.py" line="231"/>
        <source>HELLO</source>
        <translation type="obsolete">Hallo Welt</translation>
    </message>
    <message>
        <location filename="main.py" line="178"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="main.py" line="179"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="main.py" line="193"/>
        <source>Stuff</source>
        <translation>Gegenstand</translation>
    </message>
    <message>
        <location filename="main.py" line="595"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="main.py" line="596"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="main.py" line="597"/>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="main.py" line="598"/>
        <source>Weight</source>
        <translation>Gewicht</translation>
    </message>
    <message>
        <location filename="main.py" line="553"/>
        <source>Dimension of the garage</source>
        <translation>Dimension der Garage</translation>
    </message>
    <message>
        <location filename="main.py" line="592"/>
        <source>Dimensions of the objects to be stored</source>
        <translation>Dimensionen der zu verstauenden Gegenstände</translation>
    </message>
    <message>
        <location filename="main.py" line="652"/>
        <source>Result</source>
        <translation>Ergebnis</translation>
    </message>
    <message>
        <location filename="main.py" line="655"/>
        <source>Volume of the garage</source>
        <translation>Volumen der Garage</translation>
    </message>
    <message>
        <location filename="main.py" line="659"/>
        <source>Volume of the items</source>
        <translation>Volumen der Gegenstände</translation>
    </message>
    <message>
        <location filename="main.py" line="663"/>
        <source>Free space in the garage</source>
        <translation>Freier Raum in der Garage</translation>
    </message>
    <message>
        <location filename="main.py" line="667"/>
        <source>Total weight</source>
        <translation>Gesamtgewicht</translation>
    </message>
    <message>
        <location filename="main.py" line="212"/>
        <source>New (Ctrl+N)</source>
        <translation>Neu (Strg+N)</translation>
    </message>
    <message>
        <location filename="main.py" line="213"/>
        <source>Open... (Ctrl+O)</source>
        <translation>Öffnen... (Strg+O)</translation>
    </message>
    <message>
        <location filename="main.py" line="214"/>
        <source>Save (Ctrl+S)</source>
        <translation>Speichern (Strg+S)</translation>
    </message>
    <message>
        <location filename="main.py" line="215"/>
        <source>Export to EXCEL...</source>
        <translation>Export nach EXCEL...</translation>
    </message>
    <message>
        <location filename="main.py" line="216"/>
        <source>Information about the application</source>
        <translation>Informationen über das Programm</translation>
    </message>
    <message>
        <location filename="main.py" line="217"/>
        <source>Quit the application (Strg+Q)</source>
        <translation>Programm beenden (Strg+Q)</translation>
    </message>
    <message>
        <location filename="main.py" line="408"/>
        <source>Garage</source>
        <translation>Garage</translation>
    </message>
    <message>
        <location filename="main.py" line="336"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="main.py" line="345"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="main.py" line="362"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="main.py" line="401"/>
        <source> CSV-file</source>
        <translation type="obsolete">CSV-Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="544"/>
        <source>All files</source>
        <translation>Alle Dateien</translation>
    </message>
    <message>
        <location filename="main.py" line="460"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="461"/>
        <source>saved</source>
        <translation>gespeichert</translation>
    </message>
    <message>
        <location filename="main.py" line="477"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="main.py" line="541"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="main.py" line="463"/>
        <source> EXCEL-file</source>
        <translation type="obsolete">EXCEL-Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="724"/>
        <source>Error in the garage dimension</source>
        <translation>Fehler in der Garagen-Dimension</translation>
    </message>
    <message>
        <location filename="main.py" line="777"/>
        <source>Error in the dimensions of the objects to be stored</source>
        <translation>Fehler in den Dimensionen der zu verstauenden Gegenstände</translation>
    </message>
    <message>
        <location filename="main.py" line="671"/>
        <source>Successfully exported to EXCEL</source>
        <translation>Erfolgreich nach EXCEL exportiert</translation>
    </message>
    <message>
        <location filename="main.py" line="478"/>
        <source>CSV-file</source>
        <translation>CSV-Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="542"/>
        <source>EXCEL-file</source>
        <translation>EXCEL-Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="73"/>
        <source>There are unsaved entries. Without saving, all changes are lost. Continue anyway?</source>
        <translation>Es gibt  ungespeicherte Einträge. Ohne zu speichern, gehen alle Änderungen verloren. Trotzdem fortfahren?</translation>
    </message>
    <message>
        <location filename="main.py" line="147"/>
        <source>Garage Space Calculator</source>
        <translation>Garagenraum-Rechner</translation>
    </message>
    <message>
        <location filename="utils.py" line="40"/>
        <source>Calculates available garage space</source>
        <translation>Berechnet zur Verfügung stehenden Garagenraum</translation>
    </message>
    <message>
        <location filename="main.py" line="199"/>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="utils.py" line="41"/>
        <source>Idea</source>
        <translation>Idee</translation>
    </message>
    <message>
        <location filename="utils.py" line="45"/>
        <source>Used icons: Theme</source>
        <translation>Verwendete Icons: Thema</translation>
    </message>
    <message>
        <location filename="utils.py" line="45"/>
        <source>from</source>
        <translation>von</translation>
    </message>
    <message>
        <location filename="utils.py" line="48"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>

==> v0.7.tar.gz: garagecalc1/i18n/de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>TableWidget</name>
    <message>
        <location filename="clsTableWidget.py" line="96"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="97"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="98"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="367"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="115"/>
        <source>Cut row</source>
        <translation>Zeile ausschneiden</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="116"/>
        <source>Copy row</source>
        <translation>Zeile kopieren</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="117"/>
        <source>Paste row</source>
        <translation>Zeile einfügen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="119"/>
        <source>Insert row before</source>
        <translation>Zeile oberhalb einfügen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="120"/>
        <source>Insert row after</source>
        <translation>Zeile unterhalb einfügen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="122"/>
        <source>Remove row</source>
        <translation>Zeile entfernen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="123"/>
        <source>Delete items</source>
        <translation>Zellinhalte löschen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="158"/>
        <source>Row Nr.</source>
        <translation>Zeile Nr.</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="159"/>
        <source>to be removed?</source>
        <translation>entfernen?</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="159"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="clsTableWidget.py" line="367"/>
        <source>Delete cell content?</source>
        <translation>Zellinhalt löschen?</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="clsTableWidget.py" line="231"/>
        <source>HELLO</source>
        <translation type="obsolete">Hallo Welt</translation>
    </message>
    <message>
        <location filename="main.py" line="330"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="main.py" line="332"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="main.py" line="242"/>
        <source>Stuff</source>
        <translation>Gegenstand</translation>
    </message>
    <message>
        <location filename="main.py" line="759"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="main.py" line="760"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="main.py" line="761"/>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="main.py" line="762"/>
        <source>Weight</source>
        <translation>Gewicht</translation>
    </message>
    <message>
        <location filename="main.py" line="727"/>
        <source>Dimension of the garage</source>
        <translation>Dimension der Garage</translation>
    </message>
    <message>
        <location filename="main.py" line="755"/>
        <source>Dimensions of the objects to be stored</source>
        <translation>Dimensionen der zu verstauenden Gegenstände</translation>
    </message>
    <message>
        <location filename="main.py" line="847"/>
        <source>Result</source>
        <translation>Ergebnis</translation>
    </message>
    <message>
        <location filename="main.py" line="850"/>
        <source>Volume of the garage</source>
        <translation>Volumen der Garage</translation>
    </message>
    <message>
        <location filename="main.py" line="854"/>
        <source>Volume of the items</source>
        <translation>Volumen der Gegenstände</translation>
    </message>
    <message>
        <location filename="main.py" line="859"/>
        <source>Free space in the garage</source>
        <translation>Freier Raum in der Garage</translation>
    </message>
    <message>
        <location filename="main.py" line="864"/>
        <source>Total weight</source>
        <translation>Gesamtgewicht</translation>
    </message>
    <message>
        <location filename="main.py" line="261"/>
        <source>New (Ctrl+N)</source>
        <translation>Neu (Strg+N)</translation>
    </message>
    <message>
        <location filename="main.py" line="262"/>
        <source>Open... (Ctrl+O)</source>
        <translation>Öffnen... (Strg+O)</translation>
    </message>
    <message>
        <location filename="main.py" line="263"/>
        <source>Save (Ctrl+S)</source>
        <translation>Speichern (Strg+S)</translation>
    </message>
    <message>
        <location filename="main.py" line="264"/>
        <source>Export to EXCEL...</source>
        <translation>Export nach EXCEL...</translation>
    </message>
    <message>
        <location filename="main.py" line="265"/>
        <source>Information about the application</source>
        <translation>Informationen über das Programm</translation>
    </message>
    <message>
        <location filename="main.py" line="266"/>
        <source>Quit the application (Strg+Q)</source>
        <translation>Programm beenden (Strg+Q)</translation>
    </message>
    <message>
        <location filename="main.py" line="532"/>
        <source>Garage</source>
        <translation>Garage</translation>
    </message>
    <message>
        <location filename="main.py" line="459"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="main.py" line="468"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="main.py" line="492"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="main.py" line="401"/>
        <source> CSV-file</source>
        <translation type="obsolete">CSV-Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="718"/>
        <source>All files</source>
        <translation>Alle Dateien</translation>
    </message>
    <message>
        <location filename="main.py" line="597"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="598"/>
        <source>saved</source>
        <translation>gespeichert</translation>
    </message>
    <message>
        <location filename="main.py" line="614"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="main.py" line="715"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="main.py" line="463"/>
        <source> EXCEL-file</source>
        <translation type="obsolete">EXCEL-Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="929"/>
        <source>Error in the garage dimension</source>
        <translation>Fehler in der Garagen-Dimension</translation>
    </message>
    <message>
        <location filename="main.py" line="990"/>
        <source>Error in the dimensions of the objects to be stored</source>
        <translation>Fehler in den Dimensionen der zu verstauenden Gegenstände</translation>
    </message>
    <message>
        <location filename="main.py" line="871"/>
        <source>Successfully exported to EXCEL</source>
        <translation>Erfolgreich nach EXCEL exportiert</translation>
    </message>
    <message>
        <location filename="main.py" line="615"/>
        <source>CSV-file</source>
        <translation>CSV-Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="716"/>
        <source>EXCEL-file</source>
        <translation>EXCEL-Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="100"/>
        <source>There are unsaved entries. Without saving, all changes are lost. Continue anyway?</source>
        <translation>Es gibt  ungespeicherte Einträge. Ohne zu speichern, gehen alle Änderungen verloren. Trotzdem fortfahren?</translation>
    </message>
    <message>
        <location filename="main.py" line="147"/>
        <source>Garage Space Calculator</source>
        <translation type="obsolete">Garagenraum-Rechner</translation>
    </message>
    <message>
        <location filename="utils.py" line="45"/>
        <source>Calculates available garage space</source>
        <translation>Berechnet zur Verfügung stehenden Garagenraum</translation>
    </message>
    <message>
        <location filename="main.py" line="763"/>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <location filename="main.py" line="334"/>
        <source>Unit of Measurements</source>
        <translation>Maßeinheit</translation>
    </message>
    <message>
        <location filename="main.py" line="335"/>
        <source>Length units</source>
        <translation>Längeneinheit</translation>
    </message>
    <message>
        <location filename="main.py" line="336"/>
        <source>Mass units</source>
        <translation>Masseeinheit</translation>
    </message>
    <message>
        <location filename="main.py" line="321"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="main.py" line="382"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="main.py" line="1095"/>
        <source>Do you want to convert all existing stuff of type length to the new unit of measurement (UOM)</source>
        <translation>Möchten Sie alle vorhandenen Gegenstände vom Typ Länge auf die neue Maßeinheit  umrechnen</translation>
    </message>
    <message>
        <location filename="main.py" line="1127"/>
        <source>UOM conversion</source>
        <translation>Einheiten Umrechnung</translation>
    </message>
    <message>
        <location filename="main.py" line="1126"/>
        <source>Do you want to convert all existing stuff of type mass to the new unit of measurement (UOM)</source>
        <translation>Möchten Sie alle vorhandenen Gegenstände vom Typ Gewicht auf die neue Maßeinheit  umrechnen</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="utils.py" line="46"/>
        <source>Idea</source>
        <translation>Idee</translation>
    </message>
    <message>
        <location filename="utils.py" line="45"/>
        <source>Used icons: Theme</source>
        <translation type="obsolete">Verwendete Icons: Thema</translation>
    </message>
    <message>
        <location filename="utils.py" line="50"/>
        <source>from</source>
        <translation>von</translation>
    </message>
    <message>
        <location filename="utils.py" line="55"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="utils.py" line="50"/>
        <source>Used icons</source>
        <translation>Verwendete Icons</translation>
    </message>
    <message>
        <location filename="utils.py" line="51"/>
        <source>Currently opened file</source>
        <translation>Aktuell geöffnete Datei</translation>
    </message>
    <message>
        <location filename="utils.py" line="52"/>
        <source>Location of the Ini-file</source>
        <translation>Dateipfad der Ini-Datei</translation>
    </message>
</context>
</TS>
